@@ -5,7 +5,7 @@ use warnings;
 use CPAN::Meta::Requirements;
 
 use Exporter 'import';
-our @EXPORT_OK = qw(merge_version);
+our @EXPORT_OK = qw(merge_version _yaml_hash);
 
 my $TEST_PACKAGE = '__TEST_PACKAGE__';
 
@@ -17,4 +17,14 @@ sub merge_version {
     $r->requirements_for_module($TEST_PACKAGE);
 }
 
+{
+    my $YAML;
+    sub _yaml_hash {
+        my ($hash, $indent) = @_;
+        $YAML ||= do { require YAML::PP; YAML::PP->new(header => 0) };
+        my @string = split /\n/, $YAML->dump_string($hash);
+        map { "$indent$_" } @string;
+    }
+}
+
 1;
